@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,8 +27,7 @@
 #include <kpluginfactory.h>
 #include <QDir>
 
-K_PLUGIN_FACTORY_WITH_JSON(GearyImporterFactory, "gearyimporter.json", registerPlugin<GearyImportData>();
-                           )
+K_PLUGIN_CLASS_WITH_JSON(GearyImportData, "gearyimporter.json")
 
 GearyImportData::GearyImportData(QObject *parent, const QList<QVariant> &)
     : LibImportWizard::AbstractImporter(parent)
