@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -28,7 +28,7 @@ class CSVImportExportPluginInterface : public KAddressBookImportExport::KAddress
     Q_OBJECT
 public:
     explicit CSVImportExportPluginInterface(QObject *parent = nullptr);
-    ~CSVImportExportPluginInterface();
+    ~CSVImportExportPluginInterface() override;
 
     void createAction(KActionCollection *ac) override;
     void exec() override;
