@@ -28,6 +28,14 @@ class QJsonArray;
 /** Serialization/deserialization code for JSON-LD data. */
 namespace JsonLdDocument {
 QVector<QVariant> fromJson(const QJsonArray &array);
+QJsonArray toJson(const QVector<QVariant> &data);
+
+/** Read property @p name on object @p obj. */
+QVariant readProperty(const QVariant &obj, const char *name);
+/** Set property @p name on object @p obj to value @p value. */
+void writeProperty(QVariant &obj, const char *name, const QVariant &value);
+/** Removes property @p name on object @p obj. */
+void removeProperty(QVariant &obj, const char *name);
 }
 
 #endif // JSONLDDOCUMENT_H
