@@ -19,7 +19,7 @@
 
 #include "semanticmemento.h"
 
-SemanticMemento::~SemanticMemento() = default;
+#include <KMime/ContentIndex>
 
 void SemanticMemento::detach()
 {
@@ -30,6 +30,16 @@ bool SemanticMemento::isEmpty() const
     return m_data.isEmpty();
 }
 
+bool SemanticMemento::isParsed(const KMime::ContentIndex &index) const
+{
+    return m_parsedParts.contains(index);
+}
+
+void SemanticMemento::setParsed(const KMime::ContentIndex &index)
+{
+    m_parsedParts.insert(index);
+}
+
 QVector<QVariant> SemanticMemento::data() const
 {
     return m_data;
@@ -38,4 +48,28 @@ QVector<QVariant> SemanticMemento::data() const
 void SemanticMemento::setData(const QVector<QVariant> &data)
 {
     m_data = data;
+    m_expanded.resize(data.size());
+}
+
+QVector<bool> SemanticMemento::expanded() const
+{
+    return m_expanded;
+}
+
+void SemanticMemento::toggleExpanded(int index)
+{
+    if (index >= m_expanded.size()) {
+        return;
+    }
+    m_expanded[index] = !m_expanded.at(index);
+}
+
+bool SemanticMemento::hasStructuredData() const
+{
+    return m_foundStructuredData && !isEmpty();
+}
+
+void SemanticMemento::setStructuredDataFound(bool f)
+{
+    m_foundStructuredData = f;
 }
