@@ -3,7 +3,7 @@
   This file is part of KMail, the KDE mail client.
   Copyright (c) 2004 Till Adam <adam@kde.org>
   Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
-  Copyright (C) 2012-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2012-2018 Laurent Montel <montel@kde.org>
 
   KMail is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@
 #include <MessageViewer/MessagePartRenderPlugin>
 
 #include <MimeTreeParser/BodyPart>
-#include <MimeTreeParser/HtmlWriter>
+#include <MessageViewer/HtmlWriter>
 #include <MimeTreeParser/MessagePart>
 #include <MimeTreeParser/NodeHelper>
 using MimeTreeParser::Interface::BodyPart;
@@ -70,7 +70,7 @@ class Formatter : public MessageViewer::MessagePartRendererBase
 public:
     Formatter() = default;
 
-    bool render(const MimeTreeParser::MessagePartPtr &msgPart, MimeTreeParser::HtmlWriter *writer, MessageViewer::RenderContext *) const override
+    bool render(const MimeTreeParser::MessagePartPtr &msgPart, MessageViewer::HtmlWriter *writer, MessageViewer::RenderContext *) const override
     {
         QMimeDatabase db;
         auto mt = db.mimeTypeForName(QString::fromLatin1(msgPart->content()->contentType()->mimeType().toLower()));
@@ -202,10 +202,10 @@ public:
             return true;
         }
 
-        if (path.startsWith(QStringLiteral("addToAddressBook"))) {
+        if (path.startsWith(QLatin1String("addToAddressBook"))) {
             KPIM::AddContactJob *job = new KPIM::AddContactJob(a, nullptr);
             job->start();
-        } else if (path.startsWith(QStringLiteral("updateToAddressBook"))) {
+        } else if (path.startsWith(QLatin1String("updateToAddressBook"))) {
             UpdateContactJob *job = new UpdateContactJob(a.emails().first(), a, nullptr);
             job->start();
         }
@@ -257,7 +257,7 @@ public:
     QString statusBarMessage(BodyPart *part, const QString &path) const override
     {
         KContacts::Addressee a = findAddressee(part, path);
-        const bool addToAddressBook = path.startsWith(QStringLiteral("addToAddressBook"));
+        const bool addToAddressBook = path.startsWith(QLatin1String("addToAddressBook"));
         if (a.realName().isEmpty()) {
             return addToAddressBook ? i18n("Add this contact to the address book.") : i18n("Update this contact to the address book.");
         } else {
