@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,11 +22,10 @@
 #include "allheaderstyleinterface.h"
 #include "allheaderstrategy.h"
 #include <kpluginfactory.h>
+
 using namespace MessageViewer;
 
-K_PLUGIN_FACTORY_WITH_JSON(MessageViewerAllHeaderStylePluginFactory, "messageviewer_allheaderstyleplugin.json", registerPlugin<AllHeaderStylePlugin>();
-                           )
-
+K_PLUGIN_CLASS_WITH_JSON(AllHeaderStylePlugin, "messageviewer_allheaderstyleplugin.json")
 AllHeaderStylePlugin::AllHeaderStylePlugin(QObject *parent, const QList<QVariant> &)
     : MessageViewer::HeaderStylePlugin(parent)
     , mHeaderStyle(new PlainHeaderStyle)
